@@ -208,14 +208,14 @@ function prt = __dfdp__ (p, func, hook)
   idx1g2 = del1 > del2;
   idx1g2w(idxvs) = idx1g2;
   idx1le2w(idxvs) = ~idx1g2;
-  p1(idx1g2w) = max (p(idx1g2w, 1) - absdel(idx1g2w, 1), ...
+  p1(idx1g2w) = max (p(idx1g2w, 1) - absdel(idx1g2w, 1),
                      lbound(idx1g2w, 1));
-  p1(idx1le2w) = min (p(idx1le2w, 1) + absdel(idx1le2w, 1), ...
+  p1(idx1le2w) = min (p(idx1le2w, 1) + absdel(idx1le2w, 1),
                       ubound(idx1le2w, 1));
   ## double sided interval
-  p1(idxnvd) = min (p(idxnvd, 1) + absdel(idxnvd, 1), ...
+  p1(idxnvd) = min (p(idxnvd, 1) + absdel(idxnvd, 1),
                     ubound(idxnvd, 1));
-  p2(idxnvd) = max (p(idxnvd, 1) - absdel(idxnvd, 1), ...
+  p2(idxnvd) = max (p(idxnvd, 1) - absdel(idxnvd, 1),
                     lbound(idxnvd, 1));
 
   del(idxs) = p1(idxs) - p(idxs);
