@@ -36,7 +36,7 @@ int __bfgsmin_obj(double &obj, const std::string f, const octave_value_list f_ar
   f_args_new = f_args;
   f_args_new(minarg - 1) = theta;
   bool err;
-  SET_ERR (f_return = feval (f, f_args_new), err);
+  SET_ERR (f_return = OCTAVE__FEVAL (f, f_args_new), err);
   if (! err)
     {
       SET_ERR (obj = f_return(0).double_value(), err);
@@ -76,12 +76,12 @@ int __numgradient(ColumnVector &derivative, const std::string f, const octave_va
       parameter(j) = p + delta;
       success = __bfgsmin_obj(obj_right, f, f_args, parameter, minarg);
       if (! success)
-        c_verror ("__numgradient: objective function failed, can't compute numeric gradient");
+        _p_error ("__numgradient: objective function failed, can't compute numeric gradient");
       // left size
       parameter(j) = p - delta;
       success = __bfgsmin_obj(obj_left, f, f_args, parameter, minarg);
       if (! success)
-        c_verror ("__numgradient: objective function failed, can't compute numeric gradient");
+        _p_error ("__numgradient: objective function failed, can't compute numeric gradient");
       parameter(j) = p;  // restore original parameter for next round
       g(j) = (obj_right - obj_left) / (2.0*delta);
     }
@@ -98,13 +98,13 @@ int __bfgsmin_gradient(ColumnVector &derivative, const std::string f, octave_val
   if (have_analytic_gradient)
     {
       f_args(minarg - 1) = theta;
-      f_return = feval(f, f_args);
+      f_return = OCTAVE__FEVAL (f, f_args);
       g = f_return(1).column_vector_value();
     }
   else if (try_analytic_gradient)
     {
       f_args(minarg - 1) = theta;
-      f_return = feval(f, f_args);
+      f_return = OCTAVE__FEVAL (f, f_args);
       if (f_return.length() > 1)
         {
           if (f_return(1).is_real_matrix())
@@ -130,7 +130,7 @@ int __bfgsmin_gradient(ColumnVector &derivative, const std::string f, octave_val
   check_gradient.column(0) = g;
   if (check_gradient.any_element_is_inf_or_nan ())
     {
-      c_verror("__bfgsmin_gradient: gradient contains NaNs or Inf");
+      _p_error("__bfgsmin_gradient: gradient contains NaNs or Inf");
       success = 0;
     }
   else success = 1;
@@ -158,9 +158,6 @@ ColumnVector lbfgs_recursion(const int memory, const Matrix sigmas, const Matrix
     }
   else
     {
-      const int k = d.rows();
-      const int n = sigmas.columns();
-      int i, j;
       ColumnVector sig = sigmas.column(memory-1);
       ColumnVector gam = gammas.column(memory-1);
       double rho;
@@ -178,7 +175,6 @@ ColumnVector lbfgs_recursion(const int memory, const Matrix sigmas, const Matrix
 int __bisectionstep(double &step, double &obj, const std::string f, const octave_value_list f_args, const ColumnVector x, const ColumnVector dx, const int minarg, const int verbose)
 {
   double best_obj, improvement, improvement_0;
-  int found_improvement;
   ColumnVector trial;
   // initial values
   best_obj = obj;
@@ -260,7 +256,7 @@ int __newtonstep(double &step, double &obj, const std::string f, const octave_va
       found_improvement = __bisectionstep(step, obj, f, f_args, x, dx, minarg, verbose);
     }
   else found_improvement = 1;
-  if (xisnan(obj)) {
+  if (OCTAVE__MATH__ISNAN (obj)) {
     obj = obj_0;
     if (verbose) warning("__stepsize: objective function crash in Newton step, falling back to bisection");
     found_improvement = __bisectionstep(step, obj, f, f_args, x, dx, minarg, verbose);
@@ -280,7 +276,7 @@ Users should not use this directly. Use bfgsmin.m instead")
     gradient_ok, i, j, k, conv_fun, conv_param, conv_grad, have_gradient,
     try_gradient, warnings;
   double func_tol, param_tol, gradient_tol, stepsize, obj_value, obj_in,
-    last_obj_value, obj_value2, denominator, test;
+    last_obj_value, denominator, test;
   Matrix H, H1, H2;
   ColumnVector thetain, d, g, g_new, p, q, sig, gam;
 
