@@ -20,23 +20,30 @@
 
 #include "error-helpers.h"
 
+#if defined (OCTAVE_HAVE_F77_INT_TYPE)
+#  define TO_F77_INT(x) octave::to_f77_int (x)
+#else
+typedef octave_idx_type F77_INT;
+#  define TO_F77_INT(x) (x)
+#endif
+
 extern "C"
 {
   F77_RET_T
   F77_FUNC (ddisna, DDISNA) (F77_CONST_CHAR_ARG_DECL,
-                             const octave_idx_type&,
-                             const octave_idx_type&,
+                             const F77_INT&,
+                             const F77_INT&,
                              const double*,
                              double*,
-                             octave_idx_type&);
+                             F77_INT&);
 
   F77_RET_T
   F77_FUNC (sdisna, SDISNA) (F77_CONST_CHAR_ARG_DECL,
-                             const octave_idx_type&,
-                             const octave_idx_type&,
+                             const F77_INT&,
+                             const F77_INT&,
                              const float*,
                              float*,
-                             octave_idx_type&);
+                             F77_INT&);
 }
 
 DEFUN_DLD (__disna_optim__, args, ,
@@ -77,7 +84,7 @@ Undocumented internal function.\n\
   else
     job = job_str[0];
 
-  octave_idx_type m, n, l;
+  F77_INT m, n, l;
   bool single;
   octave_value d;
 
@@ -117,13 +124,13 @@ Undocumented internal function.\n\
         }
       else
         {
-          CHECK_ERROR (m = args(2).idx_type_value (), retval,
+          CHECK_ERROR (m = TO_F77_INT (args(2).idx_type_value ()), retval,
                        "%s: could not convert 3rd argumet to index",
                        fname.c_str ());
-          CHECK_ERROR (n = args(3).idx_type_value (), retval,
+          CHECK_ERROR (n = TO_F77_INT (args(3).idx_type_value ()), retval,
                        "%s: could not convert 4th argumet to index",
                        fname.c_str ());
-          octave_idx_type md = m < n ? m : n;
+          F77_INT md = m < n ? m : n;
           if (l != md)
             {
               error ("%s: given dimensions don't match length of second argument",
@@ -137,7 +144,7 @@ Undocumented internal function.\n\
       return retval;
     }
 
-  octave_idx_type info;
+  F77_INT info;
 
   if (single)
     {
