@@ -29,13 +29,13 @@ any_bad_argument(const octave_value_list& args)
 {
   if (!args(0).is_string())
     {
-      c_verror("numgradient: first argument must be string holding objective function name");
+      _p_error("numgradient: first argument must be string holding objective function name");
       return true;
     }
 
-  if (!args(1).is_cell())
+  if (!args(1).OV_ISCELL ())
     {
-      c_verror("numgradient: second argument must cell array of function arguments");
+      _p_error("numgradient: second argument must cell array of function arguments");
       return true;
     }
 
@@ -47,13 +47,13 @@ any_bad_argument(const octave_value_list& args)
       SET_ERR (tmp = args(2).int_value(), err);
       if (err)
         {
-          c_verror ("numgradient: 3rd argument, if supplied,  must an integer\n\
+          _p_error ("numgradient: 3rd argument, if supplied,  must an integer\n\
 that specifies the argument wrt which differentiation is done");
           return true;
         }
           if ((tmp > args(1).length ()) || (tmp < 1))
             {
-              c_verror("numgradient: 3rd argument must be a positive integer that indicates \n\
+              _p_error("numgradient: 3rd argument must be a positive integer that indicates \n\
 which of the elements of the second argument is the\n\
 one to differentiate with respect to");
               return true;
@@ -122,7 +122,7 @@ ans =\n\
   Matrix parameter = f_args(minarg - 1).matrix_value();
 
   // initial function value
-  f_return = feval(f, f_args);
+  f_return = OCTAVE__FEVAL (f, f_args);
   obj_value = f_return(0).matrix_value();
 
   n = obj_value.rows(); // find out dimension
@@ -145,13 +145,13 @@ ans =\n\
       // right side
       parameter(j) = p + delta;
       f_args(minarg - 1) = parameter;
-      f_return = feval(f, f_args);
+      f_return = OCTAVE__FEVAL (f, f_args);
       obj_right = f_return(0).matrix_value();
 
       // left size
       parameter(j) = p - delta;
       f_args(minarg - 1) = parameter;
-      f_return = feval(f, f_args);
+      f_return = OCTAVE__FEVAL (f, f_args);
       obj_left = f_return(0).matrix_value();
 
       parameter(j) = p;  // restore original parameter
