@@ -53,14 +53,14 @@ static bool any_bad_argument(const octave_value_list& args)
   // objective function name is a string?
   if (!args(0).is_string())
     {
-      c_verror("samin: first argument must be string holding objective function name");
+      _p_error("samin: first argument must be string holding objective function name");
       return true;
     }
 
   // are function arguments contained in a cell?
-  if (!args(1).is_cell())
+  if (!args(1).OV_ISCELL ())
     {
-      c_verror("samin: second argument must cell array of function arguments");
+      _p_error("samin: second argument must cell array of function arguments");
       return true;
     }
 
@@ -70,39 +70,39 @@ static bool any_bad_argument(const octave_value_list& args)
   SET_ERR (control =args(2).cell_value(), err);
   if (err)
     {
-      c_verror("samin: third argument must cell array of algorithm controls");
+      _p_error("samin: third argument must cell array of algorithm controls");
       return true;
     }
 
   // does control have proper number of elements?
   if (!(control.numel () == 11))
     {
-      c_verror("samin: third argument must be a cell array with 11 elements");
+      _p_error("samin: third argument must be a cell array with 11 elements");
       return true;
     }
 
   // now check type of each element of control
   if (!(control(0).is_real_matrix()) && !(control(0).is_real_scalar()))
     {
-      c_verror("samin: 1st element of controls must be LB: a vector of lower bounds");
+      _p_error("samin: 1st element of controls must be LB: a vector of lower bounds");
       return true;
     }
 
   if ((control(0).is_real_matrix()) && (control(0).columns() != 1))
     {
-      c_verror("samin: 1st element of controls must be LB: a vector of lower bounds");
+      _p_error("samin: 1st element of controls must be LB: a vector of lower bounds");
       return true;
     }
 
   if (!(control(1).is_real_matrix()) && !(control(1).is_real_scalar()))
     {
-      c_verror("samin: 1st element of controls must be UB: a vector of lower bounds");
+      _p_error("samin: 1st element of controls must be UB: a vector of lower bounds");
       return true;
     }
 
   if ((control(1).is_real_matrix()) && (control(1).columns() != 1))
     {
-      c_verror("samin: 2nd element of controls must be UB: a vector of lower bounds");
+      _p_error("samin: 2nd element of controls must be UB: a vector of lower bounds");
       return true;
     }
 
@@ -110,7 +110,7 @@ static bool any_bad_argument(const octave_value_list& args)
   SET_ERR (tmp = control(2).int_value(), err);
   if (err || tmp < 1)
     {
-      c_verror("samin: 3rd element of controls must be NT: positive integer\n\
+      _p_error("samin: 3rd element of controls must be NT: positive integer\n\
 loops per temperature reduction");
       return true;
     }
@@ -118,7 +118,7 @@ loops per temperature reduction");
   SET_ERR (tmp = control(3).int_value(), err);
   if (err || tmp < 1)
     {
-      c_verror("samin: 4th element of controls must be NS: positive integer\n\
+      _p_error("samin: 4th element of controls must be NS: positive integer\n\
 loops per stepsize adjustment");
       return true;
     }
@@ -127,7 +127,7 @@ loops per stepsize adjustment");
   SET_ERR (tmp2 = control(4).double_value(), err);
   if (err || tmp < 0)
     {
-      c_verror("samin: 5th element of controls must be RT:\n\
+      _p_error("samin: 5th element of controls must be RT:\n\
 temperature reduction factor, RT > 0");
       return true;
     }
@@ -135,14 +135,14 @@ temperature reduction factor, RT > 0");
   SET_ERR (tmp2 = control(5).double_value(), err);
   if (err || tmp < 0)
     {
-      c_verror("samin: 6th element of controls must be integer MAXEVALS > 0 ");
+      _p_error("samin: 6th element of controls must be integer MAXEVALS > 0 ");
       return true;
     }
 
   SET_ERR (tmp = control(6).int_value(), err);
   if (err || tmp < 0)
     {
-      c_verror("samin: 7th element of controls must be NEPS: positive integer\n\
+      _p_error("samin: 7th element of controls must be NEPS: positive integer\n\
 number of final obj. values that must be within EPS of eachother ");
       return true;
     }
@@ -150,7 +150,7 @@ number of final obj. values that must be within EPS of eachother ");
   SET_ERR (tmp2 = control(7).double_value(), err);
   if (err || tmp2 < 0)
     {
-      c_verror("samin: 8th element of controls must must be FUNCTOL (> 0)\n\
+      _p_error("samin: 8th element of controls must must be FUNCTOL (> 0)\n\
 used to compare the last NEPS obj values for convergence test");
       return true;
     }
@@ -158,7 +158,7 @@ used to compare the last NEPS obj values for convergence test");
   SET_ERR (tmp2 = control(8).double_value(), err);
   if (err || tmp2 < 0)
     {
-      c_verror("samin: 9th element of controls must must be PARAMTOL (> 0)\n\
+      _p_error("samin: 9th element of controls must must be PARAMTOL (> 0)\n\
 used to compare the last NEPS obj values for convergence test");
       return true;
     }
@@ -166,14 +166,14 @@ used to compare the last NEPS obj values for convergence test");
   SET_ERR (tmp = control(9).int_value(), err);
   if (err || tmp < 0 || tmp > 2)
     {
-      c_verror("samin: 9th element of controls must be VERBOSITY (0, 1, or 2)");
+      _p_error("samin: 9th element of controls must be VERBOSITY (0, 1, or 2)");
       return true;
     }
 
   SET_ERR (tmp = control(10).int_value(), err);
   if (err || tmp < 0)
     {
-      c_verror("samin: 10th element of controls must be MINARG (integer)\n\
+      _p_error("samin: 10th element of controls must be MINARG (integer)\n\
                 position of argument to minimize wrt");
       return true;
     }
@@ -181,7 +181,7 @@ used to compare the last NEPS obj values for convergence test");
   // make sure that minarg points to an existing element
   if ((tmp > args(1).length ()) || (tmp < 1))
     {
-      c_verror("bfgsmin: 4th argument must be a positive integer that indicates \n\
+      _p_error("bfgsmin: 4th argument must be a positive integer that indicates \n\
 which of the elements of the second argument is the one minimization is over");
       return true;
     }
@@ -192,6 +192,9 @@ which of the elements of the second argument is the one minimization is over");
 //-------------- The annealing algorithm --------------
 DEFUN_DLD(samin, args, , "samin: simulated annealing minimization of a function. See samin_example.m\n\
 \n\
+samin will be removed from a future version of the optim package.\n\
+Equivalent functionality is now in the samin backend of nonlin_min.\n\
+\n\
 usage: [x, obj, convergence, details] = samin(\"f\", {args}, {control})\n\
 \n\
 Arguments:\n\
@@ -231,6 +234,14 @@ Returns:\n\
 Example: see samin_example\n\
 ")
 {
+  static bool warned = false;
+  if (! warned)
+    {
+      warned = true;
+      warning_with_id ("Octave:deprecated-function",
+                       "samin will be removed from a future version of the optim package, equivalent functionality is now in the samin backend of nonlin_min");
+    }
+
   int nargin = args.length();
   if (!(nargin == 3))
     {
@@ -282,7 +293,7 @@ Example: see samin_example\n\
       return octave_value_list();
     }
 
-  double f, fp, p, pp, fopt, rand_draw, ratio, t;
+  double f, fp, p, fopt, rand_draw, ratio, t;
 
   Matrix details(1,3); // record function evaluations, temperatures and function values
   RowVector info(3);
@@ -320,7 +331,7 @@ Example: see samin_example\n\
     }
 
   // Initial obj_value
-  f_return = feval(obj_fn, f_args);
+  f_return = OCTAVE__FEVAL (obj_fn, f_args);
   f = f_return(0).double_value();
   fopt = f; // give it something to compare to
   func_evals = 0; // total function evaluations (limited by maxeval)
@@ -362,7 +373,7 @@ Example: see samin_example\n\
                         }
                       // Evaluate function at new point
                       f_args(minarg - 1) = xp;
-                      f_return = feval(obj_fn, f_args);
+                      f_return = OCTAVE__FEVAL (obj_fn, f_args);
                       fp = f_return(0).double_value();
                       func_evals = func_evals + 1;
                       //  Accept the new point if the function value decreases
@@ -533,4 +544,6 @@ Example: see samin_example\n\
           x = xopt;
         }
     }
+  // silence compiler warning
+  return octave_value_list ();
 }
